on_enter_constant

Function on_enter_constant 

pub fn on_enter_constant(
    cmd: Commands<'_, '_>,
    v_segment: Single<'_, '_, Entity, With<VirtualSegment>>,
    unfinished_node: Option<Single<'_, '_, Entity, (With<TrackNode>, With<Placing>)>>,
    last_connected_block: ResMut<'_, LastConnectedBlock>,
)
“Unfinished nodes” are nodes (or more precisely the node) that were placed as fresh nodes for the current virtual segment and need to be despawned when removing the first step.